@@ -5,8 +5,14 @@ from typing import Any, NamedTuple
 from ..core import BoundModelBase, Meta, ResourceClientBase
 from .domain import Location
 
+__all__ = [
+    "BoundLocation",
+    "LocationsPageResult",
+    "LocationsClient",
+]
 
-class BoundLocation(BoundModelBase, Location):
+
+class BoundLocation(BoundModelBase[Location], Location):
     _client: LocationsClient
 
     model = Location
