@@ -1,9 +1,11 @@
 from __future__ import annotations
 
-from dateutil.parser import isoparse
-
 from ..core import BaseDomain, DomainIdentityMixin
 
+__all__ = [
+    "SSHKey",
+]
+
 
 class SSHKey(BaseDomain, DomainIdentityMixin):
     """SSHKey Domain
@@ -46,4 +48,4 @@ class SSHKey(BaseDomain, DomainIdentityMixin):
         self.fingerprint = fingerprint
         self.public_key = public_key
         self.labels = labels
-        self.created = isoparse(created) if created else None
+        self.created = self._parse_datetime(created)
