@@ -2,7 +2,14 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any, NamedTuple
 
-from ..actions import ActionsPageResult, BoundAction, ResourceActionsClient
+from ..actions import (
+    ActionSort,
+    ActionsPageResult,
+    ActionStatus,
+    BoundAction,
+    ResourceActionsClient,
+)
+from ..actions.client import ResourceClientBaseActionsMixin
 from ..core import BoundModelBase, Meta, ResourceClientBase
 from ..locations import BoundLocation, Location
 from ..ssh_keys import BoundSSHKey, SSHKey
@@ -28,8 +35,18 @@ from .domain import (
 if TYPE_CHECKING:
     from .._client import Client
 
+__all__ = [
+    "BoundStorageBox",
+    "BoundStorageBoxSnapshot",
+    "BoundStorageBoxSubaccount",
+    "StorageBoxesPageResult",
+    "StorageBoxSnapshotsPageResult",
+    "StorageBoxSubaccountsPageResult",
+    "StorageBoxesClient",
+]
 
-class BoundStorageBox(BoundModelBase, StorageBox):
+
+class BoundStorageBox(BoundModelBase[StorageBox], StorageBox):
     _client: StorageBoxesClient
 
     model = StorageBox
@@ -67,20 +84,20 @@ class BoundStorageBox(BoundModelBase, StorageBox):
     def get_actions_list(
         self,
         *,
-        status: list[str] | None = None,
-        sort: list[str] | None = None,
+        status: list[ActionStatus] | None = None,
+        sort: list[ActionSort] | None = None,
         page: int | None = None,
         per_page: int | None = None,
     ) -> ActionsPageResult:
         """
-        Returns a paginated list of Actions for a Storage Box for a specific page.
+        Returns a paginated list of Actions for a Storage Box.
 
         See https://docs.hetzner.cloud/reference/hetzner#storage-box-actions-list-actions-for-a-storage-box
 
-        :param status: Filter the actions by status. The response will only contain actions matching the specified statuses.
-        :param sort: Sort resources by field and direction.
-        :param page: Page number to return.
-        :param per_page: Maximum number of entries returned per page.
+        :param status: Filter the Actions by status.
+        :param sort: Sort Actions by field and direction.
+        :param page: Page number to get.
+        :param per_page: Maximum number of Actions returned per page.
 
         Experimental:
             Storage Box support is experimental, breaking changes may occur within minor releases.
@@ -96,8 +113,8 @@ class BoundStorageBox(BoundModelBase, StorageBox):
     def get_actions(
         self,
         *,
-        status: list[str] | None = None,
-        sort: list[str] | None = None,
+        status: list[ActionStatus] | None = None,
+        sort: list[ActionSort] | None = None,
     ) -> list[BoundAction]:
         """
         Returns all Actions for a Storage Box.
@@ -322,7 +339,7 @@ class BoundStorageBox(BoundModelBase, StorageBox):
     def get_snapshot_by_name(
         self,
         name: str,
-    ) -> BoundStorageBoxSnapshot:
+    ) -> BoundStorageBoxSnapshot | None:
         """
         Returns a single Snapshot from a Storage Box.
 
@@ -438,7 +455,7 @@ class BoundStorageBox(BoundModelBase, StorageBox):
     def get_subaccount_by_username(
         self,
         username: str,
-    ) -> BoundStorageBoxSubaccount:
+    ) -> BoundStorageBoxSubaccount | None:
         """
         Returns a single Subaccount from a Storage Box.
 
@@ -537,7 +554,7 @@ class BoundStorageBox(BoundModelBase, StorageBox):
         )
 
 
-class BoundStorageBoxSnapshot(BoundModelBase, StorageBoxSnapshot):
+class BoundStorageBoxSnapshot(BoundModelBase[StorageBoxSnapshot], StorageBoxSnapshot):
     _client: StorageBoxesClient
 
     model = StorageBoxSnapshot
@@ -561,6 +578,8 @@ class BoundStorageBoxSnapshot(BoundModelBase, StorageBoxSnapshot):
         super().__init__(client, data, complete)
 
     def _get_self(self) -> BoundStorageBoxSnapshot:
+        assert self.data_model.storage_box is not None
+        assert self.data_model.id is not None
         return self._client.get_snapshot_by_id(
             self.data_model.storage_box,
             self.data_model.id,
@@ -603,7 +622,9 @@ class BoundStorageBoxSnapshot(BoundModelBase, StorageBoxSnapshot):
         return self._client.delete_snapshot(self)
 
 
-class BoundStorageBoxSubaccount(BoundModelBase, StorageBoxSubaccount):
+class BoundStorageBoxSubaccount(
+    BoundModelBase[StorageBoxSubaccount], StorageBoxSubaccount
+):
     _client: StorageBoxesClient
 
     model = StorageBoxSubaccount
@@ -627,6 +648,8 @@ class BoundStorageBoxSubaccount(BoundModelBase, StorageBoxSubaccount):
         super().__init__(client, data, complete)
 
     def _get_self(self) -> BoundStorageBoxSubaccount:
+        assert self.data_model.storage_box is not None
+        assert self.data_model.id is not None
         return self._client.get_subaccount_by_id(
             self.data_model.storage_box,
             self.data_model.id,
@@ -737,7 +760,10 @@ class StorageBoxSubaccountsPageResult(NamedTuple):
     meta: Meta
 
 
-class StorageBoxesClient(ResourceClientBase):
+class StorageBoxesClient(
+    ResourceClientBaseActionsMixin,
+    ResourceClientBase,
+):
     """
     A client for the Storage Boxes API.
 
@@ -1006,58 +1032,46 @@ class StorageBoxesClient(ResourceClientBase):
         self,
         storage_box: StorageBox | BoundStorageBox,
         *,
-        status: list[str] | None = None,
-        sort: list[str] | None = None,
+        status: list[ActionStatus] | None = None,
+        sort: list[ActionSort] | None = None,
         page: int | None = None,
         per_page: int | None = None,
     ) -> ActionsPageResult:
         """
-        Returns a paginated list of Actions for a Storage Box for a specific page.
+        Returns a paginated list of Actions for a Storage Box.
 
         See https://docs.hetzner.cloud/reference/hetzner#storage-box-actions-list-actions-for-a-storage-box
 
-        :param storage_box: Storage Box to fetch the Actions from.
-        :param status: Filter the actions by status. The response will only contain actions matching the specified statuses.
-        :param sort: Sort resources by field and direction.
-        :param page: Page number to return.
-        :param per_page: Maximum number of entries returned per page.
+        :param storage_box: Storage Box to get the Actions for.
+        :param status: Filter the Actions by status.
+        :param sort: Sort Actions by field and direction.
+        :param page: Page number to get.
+        :param per_page: Maximum number of Actions returned per page.
 
         Experimental:
             Storage Box support is experimental, breaking changes may occur within minor releases.
         """
-        params: dict[str, Any] = {}
-        if status is not None:
-            params["status"] = status
-        if sort is not None:
-            params["sort"] = sort
-        if page is not None:
-            params["page"] = page
-        if per_page is not None:
-            params["per_page"] = per_page
-
-        response = self._client.request(
-            method="GET",
-            url=f"/storage_boxes/{storage_box.id}/actions",
-            params=params,
-        )
-        return ActionsPageResult(
-            actions=[BoundAction(self._parent.actions, o) for o in response["actions"]],
-            meta=Meta.parse_meta(response),
+        return self._get_actions_list(
+            f"{self._base_url}/{storage_box.id}",
+            status=status,
+            sort=sort,
+            page=page,
+            per_page=per_page,
         )
 
     def get_actions(
         self,
         storage_box: StorageBox | BoundStorageBox,
         *,
-        status: list[str] | None = None,
-        sort: list[str] | None = None,
+        status: list[ActionStatus] | None = None,
+        sort: list[ActionSort] | None = None,
     ) -> list[BoundAction]:
         """
         Returns all Actions for a Storage Box.
 
         See https://docs.hetzner.cloud/reference/hetzner#storage-box-actions-list-actions-for-a-storage-box
 
-        :param storage_box: Storage Box to fetch the Actions from.
+        :param storage_box: Storage Box to get the Actions for.
         :param status: Filter the actions by status. The response will only contain actions matching the specified statuses.
         :param sort: Sort resources by field and direction.
 
@@ -1279,7 +1293,7 @@ class StorageBoxesClient(ResourceClientBase):
         self,
         storage_box: StorageBox | BoundStorageBox,
         name: str,
-    ) -> BoundStorageBoxSnapshot:
+    ) -> BoundStorageBoxSnapshot | None:
         """
         Returns a single Snapshot from a Storage Box.
 
@@ -1500,7 +1514,7 @@ class StorageBoxesClient(ResourceClientBase):
         self,
         storage_box: StorageBox | BoundStorageBox,
         username: str,
-    ) -> BoundStorageBoxSubaccount:
+    ) -> BoundStorageBoxSubaccount | None:
         """
         Returns a single Subaccount from a Storage Box.
 
