@@ -2,7 +2,14 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any, NamedTuple
 
-from ..actions import ActionsPageResult, BoundAction, ResourceActionsClient
+from ..actions import (
+    ActionSort,
+    ActionsPageResult,
+    ActionStatus,
+    BoundAction,
+    ResourceActionsClient,
+)
+from ..actions.client import ResourceClientBaseActionsMixin
 from ..core import BoundModelBase, Meta, ResourceClientBase
 from .domain import (
     CreateZoneResponse,
@@ -22,8 +29,16 @@ from .domain import (
 if TYPE_CHECKING:
     from .._client import Client
 
+__all__ = [
+    "BoundZone",
+    "BoundZoneRRSet",
+    "ZonesPageResult",
+    "ZoneRRSetsPageResult",
+    "ZonesClient",
+]
 
-class BoundZone(BoundModelBase, Zone):
+
+class BoundZone(BoundModelBase[Zone], Zone):
     _client: ZonesClient
 
     model = Zone
@@ -81,20 +96,20 @@ class BoundZone(BoundModelBase, Zone):
     def get_actions_list(
         self,
         *,
-        status: list[str] | None = None,
-        sort: list[str] | None = None,
+        status: list[ActionStatus] | None = None,
+        sort: list[ActionSort] | None = None,
         page: int | None = None,
         per_page: int | None = None,
     ) -> ActionsPageResult:
         """
-        Returns all Actions for the Zone for a specific page.
+        Returns a paginated list of Actions for a Zone.
 
         See https://docs.hetzner.cloud/reference/cloud#zones-list-zones
 
-        :param status: Filter the actions by status. The response will only contain actions matching the specified statuses.
-        :param sort: Sort resources by field and direction.
-        :param page: Page number to return.
-        :param per_page: Maximum number of entries returned per page.
+        :param status: Filter the Actions by status.
+        :param sort: Sort Actions by field and direction.
+        :param page: Page number to get.
+        :param per_page: Maximum number of Actions returned per page.
         """
         return self._client.get_actions_list(
             self,
@@ -107,16 +122,16 @@ class BoundZone(BoundModelBase, Zone):
     def get_actions(
         self,
         *,
-        status: list[str] | None = None,
-        sort: list[str] | None = None,
+        status: list[ActionStatus] | None = None,
+        sort: list[ActionSort] | None = None,
     ) -> list[BoundAction]:
         """
-        Returns all Actions for the Zone.
+        Returns all Actions for a Zone.
 
         See https://docs.hetzner.cloud/reference/cloud#zones-list-zones
 
-        :param status: Filter the actions by status. The response will only contain actions matching the specified statuses.
-        :param sort: Sort resources by field and direction.
+        :param status: Filter the Actions by status.
+        :param sort: Sort Actions by field and direction.
         """
         return self._client.get_actions(
             self,
@@ -367,7 +382,7 @@ class BoundZone(BoundModelBase, Zone):
         """
         Updates records in a ZoneRRSet.
 
-        See https://docs.hetzner.cloud/reference/cloud#zone-rrset-actions-update-records-to-an-rrset
+        See https://docs.hetzner.cloud/reference/cloud#zone-rrset-actions-update-records-of-an-rrset
 
         :param rrset: RRSet to update.
         :param records: Records to update in the RRSet.
@@ -405,12 +420,17 @@ class BoundZone(BoundModelBase, Zone):
         return self._client.set_rrset_records(rrset=rrset, records=records)
 
 
-class BoundZoneRRSet(BoundModelBase, ZoneRRSet):
+class BoundZoneRRSet(BoundModelBase[ZoneRRSet], ZoneRRSet):
     _client: ZonesClient
 
     model = ZoneRRSet
 
-    def __init__(self, client: ZonesClient, data: dict, complete: bool = True):
+    def __init__(
+        self,
+        client: ZonesClient,
+        data: dict[str, Any],
+        complete: bool = True,
+    ):
         raw = data.get("zone")
         if raw is not None:
             data["zone"] = BoundZone(client, data={"id": raw}, complete=False)
@@ -422,6 +442,8 @@ class BoundZoneRRSet(BoundModelBase, ZoneRRSet):
         super().__init__(client, data, complete)
 
     def _get_self(self) -> BoundZoneRRSet:
+        assert self.data_model.zone is not None
+        assert self.data_model.type is not None
         return self._client.get_rrset(
             self.data_model.zone,
             self.data_model.name,
@@ -501,7 +523,7 @@ class BoundZoneRRSet(BoundModelBase, ZoneRRSet):
         """
         Updates records in a ZoneRRSet.
 
-        See https://docs.hetzner.cloud/reference/cloud#zone-rrset-actions-update-records-to-an-rrset
+        See https://docs.hetzner.cloud/reference/cloud#zone-rrset-actions-update-records-of-an-rrset
 
         :param records: Records to update in the RRSet.
         """
@@ -544,7 +566,10 @@ class ZoneRRSetsPageResult(NamedTuple):
     meta: Meta
 
 
-class ZonesClient(ResourceClientBase):
+class ZonesClient(
+    ResourceClientBaseActionsMixin,
+    ResourceClientBase,
+):
     """
     ZoneClient is a client for the Zone (DNS) API.
 
@@ -767,57 +792,45 @@ class ZonesClient(ResourceClientBase):
         self,
         zone: Zone | BoundZone,
         *,
-        status: list[str] | None = None,
-        sort: list[str] | None = None,
+        status: list[ActionStatus] | None = None,
+        sort: list[ActionSort] | None = None,
         page: int | None = None,
         per_page: int | None = None,
     ) -> ActionsPageResult:
         """
-        Returns all Actions for a Zone for a specific page.
+        Returns a paginated list of Actions for a Zone.
 
         See https://docs.hetzner.cloud/reference/cloud#zones-list-zones
 
-        :param zone: Zone to fetch the Actions from.
-        :param status: Filter the actions by status. The response will only contain actions matching the specified statuses.
-        :param sort: Sort resources by field and direction.
-        :param page: Page number to return.
-        :param per_page: Maximum number of entries returned per page.
+        :param zone: Zone to get the Actions for.
+        :param status: Filter the Actions by status.
+        :param sort: Sort Actions by field and direction.
+        :param page: Page number to get.
+        :param per_page: Maximum number of Actions returned per page.
         """
-        params: dict[str, Any] = {}
-        if status is not None:
-            params["status"] = status
-        if sort is not None:
-            params["sort"] = sort
-        if page is not None:
-            params["page"] = page
-        if per_page is not None:
-            params["per_page"] = per_page
-
-        response = self._client.request(
-            method="GET",
-            url=f"{self._base_url}/{zone.id_or_name}/actions",
-            params=params,
-        )
-        return ActionsPageResult(
-            actions=[BoundAction(self._parent.actions, o) for o in response["actions"]],
-            meta=Meta.parse_meta(response),
+        return self._get_actions_list(
+            f"{self._base_url}/{zone.id_or_name}",
+            status=status,
+            sort=sort,
+            page=page,
+            per_page=per_page,
         )
 
     def get_actions(
         self,
         zone: Zone | BoundZone,
         *,
-        status: list[str] | None = None,
-        sort: list[str] | None = None,
+        status: list[ActionStatus] | None = None,
+        sort: list[ActionSort] | None = None,
     ) -> list[BoundAction]:
         """
         Returns all Actions for a Zone.
 
         See https://docs.hetzner.cloud/reference/cloud#zones-list-zones
 
-        :param zone: Zone to fetch the Actions from.
-        :param status: Filter the actions by status. The response will only contain actions matching the specified statuses.
-        :param sort: Sort resources by field and direction.
+        :param zone: Zone to get the Actions for.
+        :param status: Filter the Actions by status.
+        :param sort: Sort Actions by field and direction.
         """
         return self._iter_pages(
             self.get_actions_list,
@@ -1208,7 +1221,7 @@ class ZonesClient(ResourceClientBase):
         """
         Updates records in a ZoneRRSet.
 
-        See https://docs.hetzner.cloud/reference/cloud#zone-rrset-actions-update-records-to-an-rrset
+        See https://docs.hetzner.cloud/reference/cloud#zone-rrset-actions-update-records-of-an-rrset
 
         :param rrset: RRSet to update.
         :param records: Records to update in the RRSet.
